@@ -1,3 +1,4 @@
+#!/usr/bin/env python
 import matplotlib
 matplotlib.use('PS')
 from matplotlib.matlab import *
@@ -26,6 +27,6 @@ l = plot(t1, f(t1), 'k>')
 
 ylabel('Signal 2', fontsize=12)
 xlabel('time (s)', fontsize=12)
-savefig('pstest')
+#savefig('pstest')
 show()
 
