@@ -1,13 +1,19 @@
+#!/usr/bin/env python
 import sys
+from matplotlib.ticker import MultipleLocator
 from matplotlib.matlab import *
 from data_helper import get_two_stock_data
-import Numeric as numpy
+import matplotlib.numerix as numpy
 (d1, p1, d2, p2 ) = get_two_stock_data()
 
-plot(d1, p1, 'bs', d2, p2, 'go')
+ax = subplot(111)
+lines = plot(d1, p1, 'bs', d2, p2, 'go')
+set(lines, 'data_clipping', True)
 xlabel('Days')
 ylabel('Normalized price')
-set(gca(), 'xlim', [0, 3])
+xlim( 0, 3) 
+ax.xaxis.set_major_locator(MultipleLocator(1))
+
 title('INTC vs AAPL')
 legend( ('INTC', 'AAPL') )
 #savefig('stock_demo')
