@@ -5,17 +5,15 @@ graphics contexts must implement to serve as a matplotlib backend
 
 from __future__ import division
 import sys
-from numerix import array, sqrt, pi, log
-
-from cbook import True, False
 
+from matplotlib import verbose
 from cbook import is_string_like, enumerate, True, False
 from colors import colorConverter
-from numerix import asarray, ones, Float
+from numerix import array, sqrt, pi, log, asarray, ones, Float
 from patches import Rectangle
 from transforms import lbwh_to_bbox
-        
-        
+from matplotlib import verbose
+
 class RendererBase:
 
     def open_group(self, s):
@@ -30,13 +28,12 @@ class RendererBase:
         'return the canvas width and height in display coords'
         return 1, 1
 
-    def get_text_width_height(self, s, fontsize, ismath=False):
+    def get_text_width_height(self, s, prop, ismath):
         """
         get the width and height in display coords of the string s
-        with fontsize in points
+        with FontPropertry prop
         """
         return 1,1
-
                               
     def flipy(self):
         'return true if y small numbers are top for renderer'
@@ -44,8 +41,11 @@ class RendererBase:
     
     def points_to_pixels(self, points):
         """
-        convert points to display units; unless your backend doesn't
-        have dpi, eg, postscript, you need to overrride this function
+        Convert points to display units (as a float).
+        You need to override this function (unless your backend doesn't have
+        dpi, eg, postscript or svg).
+        Many imaging systems assume some value for pixels per inch.
+        points to pixels = points * pixels_per_inch/72.0 * dpi/72.0
         """
         return points  
 
@@ -295,7 +295,6 @@ class RendererBase:
 
         If rgbFace is not None, fill the poly with it.  gc
         is a GraphicsContext instance
-
         """  
         pass # derived must override
 
@@ -341,20 +340,45 @@ class GraphicsContextBase:
               }
 
     def __init__(self):
-        self._rgb = (0.0, 0.0, 0.0)
-        self._linewidth = 1
-        self._capstyle = 'butt'
-        self._joinstyle = 'miter'
-        self._dashes = None, None
-        self._cliprect = None
-        self._linestyle = 'solid'
-        self._antialiased = 1  # use 0,1 not True, False for extension code
         self._alpha = 1.0
+        self._antialiased = 1  # use 0,1 not True, False for extension code
+        self._capstyle = 'butt'
+        self._cliprect = None
+        self._dashes = None, None
+        self._joinstyle = 'miter'
+        self._linestyle = 'solid'
+        self._linewidth = 1
+        self._rgb = (0.0, 0.0, 0.0)
     
+    def copy_properties(self, gc):
+        'Copy properties from gc to self'
+        self._alpha = gc._alpha
+        self._antialiased = gc._antialiased
+        self._capstyle = gc._capstyle
+        self._cliprect = gc._cliprect
+        self._dashes = gc._dashes
+        self._joinstyle = gc._joinstyle
+        self._linestyle = gc._linestyle
+        self._linewidth = gc._linewidth
+        self._rgb = gc._rgb
+        
+    def get_alpha(self):
+        """
+        Return the alpha value used for blending - not supported on
+        all backends
+        """
+        return self._alpha
+
     def get_antialiased(self):
-        "Return true if the object shuold try to do antialiased rendering"
+        "Return true if the object should try to do antialiased rendering"
         return self._antialiased
 
+    def get_capstyle(self):
+        """
+        Return the capstyle as a string in ('butt', 'round', 'projecting')
+        """
+        return self._capstyle
+
     def get_clip_rectangle(self):
         """
         Return the clip rectangle as (left, bottom, width, height)
@@ -371,19 +395,6 @@ class GraphicsContextBase:
         """
         return self._dashes
 
-    def get_alpha(self):
-        """
-        Return the alpha value used for blending - not supported on
-        all backends
-        """
-        return self._alpha
-
-    def get_capstyle(self):
-        """
-        Return the capstyle as a string in ('butt', 'round', 'projecting')
-        """
-        return self._capstyle
-
     def get_joinstyle(self):
         """
         Return the line join style as one of ('miter', 'round', 'bevel')
@@ -397,6 +408,12 @@ class GraphicsContextBase:
         """
         return self._linestyle
 
+    def get_linewidth(self):
+        """
+        Return the line width in points as a scalar
+        """
+        return self._linewidth
+
     def get_rgb(self):
         """
         returns a tuple of three floats from 0-1.  color can be a
@@ -404,6 +421,13 @@ class GraphicsContextBase:
         """
         return self._rgb
 
+    def set_alpha(self, alpha):
+        """
+        Set the alpha value used for blending - not supported on
+        all backends
+        """
+        self._alpha = alpha
+
     def set_antialiased(self, b):
         """
         True if object should be drawn with antialiased rendering
@@ -413,33 +437,21 @@ class GraphicsContextBase:
         if b: self._antialiased = 1
         else: self._antialiased = 0
 
+    def set_capstyle(self, cs):
+        """
+        Set the capstyle as a string in ('butt', 'round', 'projecting')
+        """
+        if cs in ('butt', 'round', 'projecting'):
+            self._capstyle = cs
+        else:
+            error_msg('Unrecognized cap style.  Found %s' % cs)
+
     def set_clip_rectangle(self, rectangle):
         """
         Set the clip rectangle with sequence (left, bottom, width, height)
         """
         self._cliprect = rectangle
 
-
-
-    def set_alpha(self, alpha):
-        """
-        Set the alpha value used for blending - not supported on
-        all backends
-        """
-        self._alpha = alpha
-
-    def set_linestyle(self, style):
-        """
-        Set the linestyle to be one of ('solid', 'dashed', 'dashdot',
-        'dotted').  
-        """
-        if style not in ('solid', 'dashed', 'dashdot', 'dotted'):
-            error_msg('Unrecognized linestyle.  Found %s' % js)
-            return
-        self._linestyle = style
-        offset, dashes = self._dashd[style]
-        self.set_dashes(offset, dashes)
-
     def set_dashes(self, dash_offset, dash_list):
         """
         Set the dash style for the gc.  dash offset is the offset
@@ -448,7 +460,7 @@ class GraphicsContextBase:
         """
         self._dashes = dash_offset, dash_list
     
-    def set_foreground(self, fg, isRGB=None):
+    def set_foreground(self, fg, isRGB=False):
         """
         Set the foreground color.  fg can be a matlab format string, a
         html hex color string, an rgb unit tuple, or a float between 0
@@ -469,6 +481,14 @@ class GraphicsContextBase:
         """
         self._rgb = (frac, frac, frac)
         
+    def set_joinstyle(self, js):
+        """
+        Set the join style to be one of ('miter', 'round', 'bevel')
+        """
+        if js in ('miter', 'round', 'bevel'):
+            self._joinstyle = js
+        else:
+            error_msg('Unrecognized join style.  Found %s' % js)
 
     def set_linewidth(self, w):
         """
@@ -476,42 +496,18 @@ class GraphicsContextBase:
         """
         self._linewidth = w
 
-    def set_capstyle(self, cs):
+    def set_linestyle(self, style):
         """
-        Set the capstyle as a string in ('butt', 'round', 'projecting')
+        Set the linestyle to be one of ('solid', 'dashed', 'dashdot',
+        'dotted').  
         """
-        if cs not in ('butt', 'round', 'projecting'):
-            error_msg('Unrecognized cap style.  Found %s' % cs)
-        self._capstyle = cs
+        if style in ('solid', 'dashed', 'dashdot', 'dotted'):
+            self._linestyle = style
+            offset, dashes = self._dashd[style]
+            self.set_dashes(offset, dashes)
+        else:
+            error_msg('Unrecognized linestyle:  Found %s' % style)
 
-    def set_joinstyle(self, js):
-        """
-        Set the join style to be one of ('miter', 'round', 'bevel')
-        """
-        
-        if js not in ('miter', 'round', 'bevel'):
-            error_msg('Unrecognized join style.  Found %s' % js)
-        self._joinstyle = js
-
-
-    def get_linewidth(self):
-        """
-        Return the line width in points as a scalar
-        """
-        return self._linewidth
-
-    def copy_properties(self, gc):
-        'Copy properties from gc to self'
-        self._rgb = gc._rgb
-        self._linewidth = gc._linewidth
-        self._capstyle = gc._capstyle
-        self._joinstyle = gc._joinstyle
-        self._linestyle = gc._linestyle
-        self._dashes = gc._dashes
-        self._cliprect = gc._cliprect
-        self._antialiased = gc._antialiased
-        self._alpha = gc._alpha
-        
 
 class MplEvent:
     """
@@ -562,14 +558,16 @@ class FigureCanvasBase:
         """
         pass
 
-    def print_figure(self, filename, dpi=300, facecolor='w', edgecolor='w'):
+    def print_figure(self, filename, dpi=300, facecolor='w', edgecolor='w',
+                     orientation='portrait'):
         """
-        Render the figure to hardcopy.  Set the figure patch face and
-        edge colors.  This is useful because some of the GUIs have a
-        gray figure face color background and you'll probably want to
-        override this on hardcopy
+        Render the figure to hardcopy. Set the figure patch face and edge
+        colors.  This is useful because some of the GUIs have a gray figure
+        face color background and you'll probably want to override this on
+        hardcopy.
+
+        orientation - only currently applies to PostScript printing.
         """
-        pass
 
     def switch_backends(self, FigureCanvasClass):
         """
@@ -659,14 +657,14 @@ class FigureManagerBase:
             self.currentAxis = a
             return a
 
-    def get_current_axis(self):
+    def get_current_axis(self, **kwargs):
         """
         Return the current axes
         """
         if self.currentAxis is not None:
             return self.currentAxis
         else:
-            self.add_subplot(111)
+            self.add_subplot(111, **kwargs)
             return self.currentAxis
 
 
@@ -864,14 +862,11 @@ class NavigationToolbar2:
 
         if event.inaxes:
 
-            xs = event.inaxes.format_xdata(event.xdata)
-            ys = event.inaxes.format_ydata(event.ydata)            
-            
-            loc = 'x=%s, y=%s'%(xs,ys)
+            s = event.inaxes.format_coord(event.xdata, event.ydata)
             if len(self.mode):
-                self.set_message('%s : %s' % (self.mode, loc))
+                self.set_message('%s : %s' % (self.mode, s))
             else:
-                self.set_message(loc)
+                self.set_message(s)
         else: self.set_message(self.mode)            
             
     def pan(self,*args):
@@ -1128,10 +1123,17 @@ class NavigationToolbar2:
     def draw(self):
         'redraw the canvases, update the locators'
         for a in self.canvas.figure.get_axes():
-            for loc in (a.xaxis.get_major_locator(),
-                        a.xaxis.get_minor_locator(),
-                        a.yaxis.get_major_locator(),
-                        a.yaxis.get_minor_locator()):
+            xaxis = getattr(a, 'xaxis', None)
+            yaxis = getattr(a, 'yaxis', None)
+            locators = []
+            if xaxis is not None:
+                locators.append(xaxis.get_major_locator())
+                locators.append(xaxis.get_minor_locator())                
+            if yaxis is not None:
+                locators.append(yaxis.get_major_locator())
+                locators.append(yaxis.get_minor_locator())                
+
+            for loc in locators:
                 loc.refresh()
         self.canvas.draw()
                        
@@ -1191,8 +1193,5 @@ def error_msg(msg, *args, **kwargs):
     """
     Alert an error condition with message
     """
-    print >>sys.stderr, msg
+    verbose.report_error('Error: %s'% msg)
     sys.exit()
-
-
-
