@@ -1,35 +1,41 @@
-# A postscript backend
-
-# postscript for mathematical drawing:
-# http://www.math.ubc.ca/people/faculty/cass/graphics/text/www/
+"""
+A PostScript backend, which can produce both PostScript .ps and
+Encapsulated PostScript .eps files.
+"""
 
 from __future__ import division
-from cStringIO import StringIO
 import sys, os
-
-from matplotlib.afm import AFM
+from cStringIO import StringIO
+from datetime import datetime
+from matplotlib import verbose, __version__
+from matplotlib._matlab_helpers import Gcf
 from matplotlib.backend_bases import RendererBase, GraphicsContextBase,\
-     FigureManagerBase, FigureCanvasBase
-
-from matplotlib.cbook import iterable, is_string_like, flatten, enumerate,\
-     get_recursive_filelist, True, False
+     FigureManagerBase, FigureCanvasBase, error_msg
 
+from matplotlib.cbook import is_string_like, True, False
 from matplotlib.figure import Figure
+
 from matplotlib.font_manager import fontManager
 from matplotlib.ft2font import FT2Font
 from matplotlib.mathtext import math_parse_s_ps, bakoma_fonts
-from matplotlib._matlab_helpers import Gcf
 from matplotlib.text import Text
 
-from matplotlib import rcParams, get_data_path
+from matplotlib import get_data_path
 
 from matplotlib.numerix import fromstring, UInt8, Float32
 import binascii
 
+backend_version = 'Level II'
+
 defaultPaperSize = 8.5,11
 
+
+
 def error_msg_ps(msg, *args):
-    print >>sys.stderr, 'Error:', msg
+    """
+    Signal an error condition -- in a GUI, popup a error dialog
+    """
+    verbose.report_error('Error: %s'% msg)
     sys.exit()
 
 
@@ -43,15 +49,18 @@ def _int_or_float(val, fmt='%1.3f'):
     if val==ival: return str(ival)
     else: return fmt%val
 
+
 _fontd = {}
 _type42 = []
 
-DEBUG = 0
 
 class RendererPS(RendererBase):
+    """
+    The renderer handles all the drawing primitives using a graphics
+    context instance that controls the colors/styles
+    """
 
     def __init__(self, width, height, pswriter):
-
         self.width = width
         self.height = height
         self._pswriter = pswriter
@@ -69,15 +78,16 @@ class RendererPS(RendererBase):
             width, height, pswriter = math_parse_s_ps(
                 s, 72, prop.get_size_in_points())
             return width, height
+
         font = self._get_font(prop)
         font.set_text(s, 0.0)
-
         w, h = font.get_width_height()
         w /= 64.0  # convert from subpixels
         h /= 64.0
         return w, h
-    
+
     def flipy(self):
+        'return true if y small numbers are top for renderer'
         return False
 
     def _get_font(self, prop):
@@ -88,7 +98,7 @@ class RendererPS(RendererBase):
             try:
                 font = FT2Font(str(fname))
             except RuntimeError, msg:
-                print >> sys.stderr, 'Could not load filename for text',fname
+                verbose.report_error('Could not load font file "%s"'%fname)
                 return None
             else:
                 _fontd[key] = font
@@ -97,59 +107,23 @@ class RendererPS(RendererBase):
         font.clear()
         size = prop.get_size_in_points()
         font.set_size(size, 72.0)
-
         return font
     
     def draw_postscript(self, ps):
         self._pswriter.write(ps)
         
     def draw_arc(self, gc, rgbFace, x, y, width, height, angle1, angle2):
-
-        ps = 'newpath %s ellipse' % _nums_to_str(
-            (x,y,0.5*width,0.5*height,angle1,angle2))
-        self._draw_ps(ps, gc, rgbFace)
-    
-    def draw_line(self, gc, x1, y1, x2, y2):
         """
-        Draw a single line from x1,y1 to x2,y2
+        Draw an arc centered at x,y with width and height and angles
+        from 0.0 to 360.0
+
+        If gcFace is not None, fill the rectangle with it.  gcEdge
+        is a GraphicsContext instance
         """
-        ps = '%s l' % _nums_to_str( (x1,y1,x2,y2) )
-        self._draw_ps(ps, gc, None)
-
-    def draw_lines(self, gc, x, y):
-        if len(x)==0: return
-        if len(x)!=len(y): error_msg_ps('x and y must be the same length')
-        j, ps = 0, []
-        
-        while j < len(x)-1001:
-            ps.append('newpath %s moveto' % _nums_to_str((x[j], y[j])))
-            for tup in zip(x[j+1:j+1001], y[j+1:j+1001]):
-                ps.append('%s lineto' % _nums_to_str(tup))
-            ps.append(self._get_gc_props_ps(gc))
-            ps.append('stroke')
-            j += 1000
-
-        ps.append('newpath %s moveto' % _nums_to_str((x[j], y[j])))
-        for tup in zip(x[j+1:], y[j+1:]):
-            ps.append('%s lineto' % _nums_to_str(tup))
-
-        self._draw_ps('\n'.join(ps), gc, None)
-        
-    def draw_rectangle(self, gc, rgbFace, x, y, width, height):
-        ps = '%s box' % _nums_to_str( (x, y, width, height) )
+        ps = '%s ellipse' % _nums_to_str( (angle1, angle2,
+                                           0.5*width, 0.5*height, x, y) )
         self._draw_ps(ps, gc, rgbFace)
 
-
-    def draw_polygon(self, gc, rgbFace, points):
-        verts = [_nums_to_str(xy) for xy in points]
-        # build a 2D postscript array
-        ps = 'newpath [ [ %s ] ] make-polygon' % ' ] [  '.join(verts)
-        self._draw_ps(ps, gc, rgbFace)
-
-    def draw_point(self, gc, x, y):
-        # todo: is there a better way to draw points in postscript?
-        self.draw_line(gc, x, y, x+1, y+1)
-
     def _rgba(self, im, flipud):
         return im.as_str(fliud)
     
@@ -180,8 +154,20 @@ class RendererPS(RendererBase):
         return lines
 
     def draw_image(self, x, y, im, origin, bbox):
+        """
+        Draw the Image instance into the current axes; x is the
+        distance in pixels from the left hand side of the canvas. y is
+        the distance from the origin.  That is, if origin is upper, y
+        is the distance from top.  If origin is lower, y is the
+        distance from bottom
 
-        flipud = origin=='lower'        
+        origin is 'upper' or 'lower'
+
+        bbox is a matplotlib.transforms.BBox instance for clipping, or
+        None
+        """
+
+        flipud = origin=='lower'
         if im.is_grayscale:
             h, w, bits = self._gray(im, flipud)
             imagecmd = "image"
@@ -195,15 +181,9 @@ class RendererPS(RendererBase):
         figh = self.height*72
         #print 'values', origin, flipud, figh, h, y
         if bbox is not None:
-            cliprect = bbox.get_bounds()
-            box = ['%1.5f'%val for val in cliprect]
-            clip =   '%s clipbox' % ' '.join(box)
-        else: clip = 'figure_clip'
+            clipx,clipy,clipw,cliph = bbox.get_bounds()
+            clip = '%s clipbox' % _nums_to_str( (clipw, cliph, clipx, clipy) )
         if not flipud: y = figh-(y+h)
-        if 0:
-            print "RendererPS.draw_image:"
-            print "x, y: ", x, y
-            print "xscale, yscale:", xscale, yscale
         ps = """gsave
 %(clip)s
 %(x)s %(y)s translate
@@ -217,13 +197,127 @@ currentfile DataString readhexstring pop
 grestore
 """ % locals()
         self.draw_postscript(ps)
+    
+    def draw_line(self, gc, x1, y1, x2, y2):
+        """
+        Draw a single line from x1,y1 to x2,y2
+        """
+        ps = '%s line' % _nums_to_str( (x1,y1,x2,y2) )
+        self._draw_ps(ps, gc, None)
+
+    def draw_lines(self, gc, x, y):
+        """
+        x and y are equal length arrays, draw lines connecting each
+        point in x, y
+        """
+        if len(x)==0: return
+        j, ps = 0, []
+        
+        while j < len(x)-1001:
+            ps.append('newpath %s m' % _nums_to_str((x[j], y[j])))
+            for tup in zip(x[j+1:j+1001], y[j+1:j+1001]):
+                ps.append('%s l' % _nums_to_str(tup))
+            ps.append(self._get_gc_props_ps(gc))
+            ps.append('stroke')
+            j += 1000
+
+        ps.append('newpath %s m' % _nums_to_str((x[j], y[j])))
+        for tup in zip(x[j+1:], y[j+1:]):
+            ps.append('%s l' % _nums_to_str(tup))
+
+        self._draw_ps('\n'.join(ps), gc, None)
+
+    def draw_point(self, gc, x, y):
+        """
+        Draw a single point at x,y
+        """
+        # todo: is there a better way to draw points in postscript?
+        self.draw_line(gc, x, y, x+1, y+1)
+
+    def draw_polygon(self, gc, rgbFace, points):
+        """
+        Draw a polygon.  points is a len vertices tuple, each element
+        giving the x,y coords a vertex
+
+        If rgbFace is not None, fill the poly with it.  gc
+        is a GraphicsContext instance
+        """
+        ps = "newpath\n"
+        ps += "%s m\n" % _nums_to_str(points[0])
+        for x,y in points[1:]:
+            ps += "%s l\n" % _nums_to_str( (x,y) )
+        ps += "closepath\n"
+        self._draw_ps(ps, gc, rgbFace)
+        
+    def draw_rectangle(self, gc, rgbFace, x, y, width, height):
+        """
+        Draw a rectangle with lower left at x,y with width and height.
+
+        If gcFace is not None, fill the rectangle with it.  gcEdge
+        is a GraphicsContext instance
+        """
+        ps = '%s box' % _nums_to_str( (width, height, x, y) )
+        self._draw_ps(ps, gc, rgbFace)
+
+    def draw_text(self, gc, x, y, s, prop, angle, ismath):
+        """
+        draw a Text instance
+        """
+
+        if ismath:
+            return self.draw_mathtext(gc, x, y, s, prop, angle)
+        
+        font = self._get_font(prop)
+        font.set_text(s,0)
+
+        pos = _nums_to_str((x, y))
+        thetext = '(%s)' % s
+        fontname = font.get_sfnt()[(1,0,0,6)]
+        fontsize = prop.get_size_in_points()
+        rotate = '%1.1f rotate' % angle
+        descent = font.get_descent() / 64.0
+        setcolor = '%1.3f %1.3f %1.3f setrgbcolor' % gc.get_rgb()
+        ps = """gsave
+/%(fontname)s findfont
+%(fontsize)s scalefont
+setfont
+%(pos)s m
+%(rotate)s
+0 %(descent).2f rmoveto
+%(thetext)s
+%(setcolor)s
+show
+grestore
+""" % locals()
+        self.draw_postscript(ps)
+
+    def get_ps(self):
+        return self._pswriter.getvalue()
+
+    def new_gc(self):
+        return GraphicsContextPS()
+
+    def _draw_ps(self, ps, gc, rgbFace):
+        if rgbFace is not None:
+            fill = 'gsave %1.3f %1.3f %1.3f setrgbcolor fill grestore'%rgbFace
+        else:
+            fill = ''
+        gcprops = self._get_gc_props_ps(gc)
+        clip = self._get_gc_clip_ps(gc)
+        s = """gsave
+%(clip)s
+%(ps)s
+%(gcprops)s
+%(fill)s
+stroke
+grestore
+""" % locals()
+        self._pswriter.write(s)
 
     def draw_mathtext(self, gc, x, y, s, prop, angle):
         """
         Draw the math text using matplotlib.mathtext
         """
-        if DEBUG:
-            print 'RendererPS.draw_mathtext'
         fontsize = prop.get_size_in_points()
         width, height, pswriter = math_parse_s_ps(s, 72, fontsize)
         thetext = pswriter.getvalue()
@@ -235,73 +329,11 @@ grestore
 """ % locals()
         self.draw_postscript(ps)
 
-    def draw_text(self, gc, x, y, s, prop, angle, ismath):
-        """
-        draw a Text instance
-        """
-
-        if ismath:
-            return self.draw_mathtext(gc, x, y, s, prop, angle)
-        
-        font = self._get_font(prop)
-        font.set_text(s, 0.0)
-        l, b = 0., 0.
-        w, h = font.get_width_height()
-
-        fontsize = prop.get_size_in_points()
-
-        if angle==90: l,b = -b, l # todo generalize for arb rotations
-        pos = _nums_to_str((x-l, y-b))
-        thetext = '(%s)' % s
-        
-        fontname = font.get_sfnt()[(1,0,0,6)]
-        fontsize = prop.get_size_in_points()
-        rotate = '%1.1f rotate' % angle
-        setcolor = '%1.3f %1.3f %1.3f setrgbcolor' % gc.get_rgb()
-        ps = """gsave
-/%(fontname)s findfont
-%(fontsize)s scalefont
-setfont
-%(pos)s rmoveto
-%(rotate)s
-%(thetext)s
-%(setcolor)s
-show
-grestore
-""" % locals()
-        self.draw_postscript(ps)
-        
-    def get_ps(self):
-        return self._pswriter.getvalue()
-    
-    def finish(self):
-        self._pswriter.write('showpage\n')
-
-    def new_gc(self):
-        return GraphicsContextPS()
-
-    def _draw_ps(self, ps, gc, rgbFace):
-        if rgbFace is not None:
-            fill = '%1.3f %1.3f %1.3f setrgbcolor fill' % rgbFace
-        else: fill = ''
-        gcprops = self._get_gc_props_ps(gc)
-        clip = self._get_gc_clip_ps(gc)
-        s = """gsave
-%(clip)s
-%(ps)s
-%(gcprops)s
-gsr
-%(fill)s
-grestore
-""" % locals()
-        self._pswriter.write(s)
-
-    
     def _get_gc_clip_ps(self, gc):
         cliprect = gc.get_clip_rectangle()
         if cliprect is not None:
-            box = ['%1.5f'%val for val in cliprect]
-            return  '%s clipbox' % ' '.join(box)
+            clipx,clipy,clipw,cliph=cliprect
+            return '%s clipbox' % _nums_to_str( (clipw, cliph, clipx, clipy) )
         return ''
         
     def _get_gc_props_ps(self, gc):
@@ -315,7 +347,7 @@ grestore
         offset, seq = gc.get_dashes()
         if seq is not None:
             seq = ' '.join(['%d'%val for val in  seq])
-            dashes = '[%s] %d setdash' % (seq, offset)            
+            dashes = '[%s] %d setdash' % (seq, offset)
         else:
             dashes = None
 
@@ -326,6 +358,10 @@ grestore
 class GraphicsContextPS(GraphicsContextBase):
 
     def set_linestyle(self, style):
+        """
+        Set the linestyle to be one of ('solid', 'dashed', 'dashdot',
+        'dotted').
+        """
         GraphicsContextBase.set_linestyle(self, style)
         offset, dashes = self._dashd[style]
         self.set_dashes(offset, dashes)
@@ -426,247 +462,225 @@ FontName currentdict end definefont pop""" % locals()
 
 
 class FigureCanvasPS(FigureCanvasBase):
-
     basepath = get_data_path()
 
     def draw(self):
         pass
     
-    def print_figure(self, filename, dpi=72,
+    def print_figure(self, outfile, dpi=72,
                      facecolor='w', edgecolor='w',
                      orientation='portrait'):
-        'dpi is ignored for PS output, it depends on the output device'
-        # ignore dpi for ps
-        self.figure.dpi.set(72)
+        """
+        Render the figure to hardcopy.  Set the figure patch face and
+        edge colors.  This is useful because some of the GUIs have a
+        gray figure face color background and you'll probably want to
+        override this on hardcopy
+
+        If outfile is a string, it is interpreted as a file name.
+        If the extension matches .ep* write encapsulated postscript,
+        otherwise write a stand-alone PostScript file.
+
+        If outfile is a file object, a stand-alone PostScript file is
+        written into this file object.
+        """
+
+        if  isinstance(outfile, file):
+            # assume plain PostScript and write to fileobject
+            isEPSF = False
+            fh = outfile
+            needsClose = False
+            title = None
+        else:
+            basename, ext = os.path.splitext(outfile)
+            if not ext: outfile += '.ps'
+            isEPSF = ext.lower().startswith('.ep')
+            try:
+                fh = file(outfile, 'w')
+            except IOError:
+                error_msg_ps('Could not open %s for writing' % outfile)
+            needsClose = True
+            title = outfile
         
         # center the figure on the paper
+        self.figure.dpi.set(72)        # ignore the passsed dpi setting for PS
+        width, height = self.figure.get_size_inches()
+
         if orientation=='landscape':
             isLandscape = True
-            defaultHeight, defaultWidth = defaultPaperSize
+            paperHeight, paperWidth = defaultPaperSize
         else:
             isLandscape = False
-            defaultWidth, defaultHeight = defaultPaperSize
+            paperWidth, paperHeight = defaultPaperSize
 
+        xo = 72*0.5*(paperWidth - width)
+        yo = 72*0.5*(paperHeight - height)
 
-        width, height = self.figure.get_size_inches()
-        xo = 72*0.5*(defaultWidth - width)
-        yo = 72*0.5*(defaultHeight - height)
+        l, b, w, h = self.figure.bbox.get_bounds()
+        llx = xo
+        lly = yo
+        urx = llx + w
+        ury = lly + h
 
+        if isLandscape:
+            xo, yo = 72*paperHeight - yo, xo
+            rotation = 90
+        else:
+            rotation = 0
+
+        # generate PostScript code for the figure and store it in a string
         origfacecolor = self.figure.get_facecolor()
         origedgecolor = self.figure.get_edgecolor()
         self.figure.set_facecolor(facecolor)
         self.figure.set_edgecolor(edgecolor)
 
-
-        basename, ext = os.path.splitext(filename)
-        if not len(ext): filename += '.ps'
-
         self._pswriter = StringIO()
-
-        if ext.lower().startswith('.ep'):
-
-            # looks like encapsulated postscript
-            l, b, w, h = self.figure.bbox.get_bounds()
-            llx = xo
-            lly = yo
-            urx = llx + w 
-            ury = lly + h 
-            bboxstr = '%%BoundingBox:    %d %d %d %d' % (llx, lly, urx, ury)
-
-            pstype = 'PS-Adobe-2.0 EPSF-2.0'
-        else:
-            pstype = 'PS'
-            bboxstr = ''
-
-        if isLandscape:
-            xo, yo = 72*defaultHeight - yo, xo
-            rotation = 90
-        else:
-            rotation = 0
-
-        self._pswriter.write('%1.3f %1.3f translate\n' % (xo, yo))
-        self._pswriter.write('%d rotate\n' % rotation)
-        self._pswriter.write('/figure_clip {0 0 %1.3f %1.3f clipbox} def\n' %
-                             (width*72,
-                              height*72))
-        self._pswriter.write('figure_clip\n')
-
-        if 0:
-            print "FigureCanvasPS.print_figure:"
-            print "orientation:", orientation
-            print "DPI:", self.figure.dpi.get()
-            print "defaultWidth:",defaultWidth, "defaultHeight:",defaultHeight
-            print "figsize:",self.figure.get_size()
-            print "bboxstr:", bboxstr
-            print "pstype:", pstype
-            print "translation xo, yo:", xo, yo
-            print "rotation:", rotation
-
         renderer = RendererPS(width, height, self._pswriter)
         self.figure.draw(renderer)
-        renderer.finish()
-
-        try: fh = file(filename, 'w')
-        except IOError:
-            error_msg_ps('Could not open %s for writing' % filename)
-            return
-
-        print >>fh, _psProlog % (pstype, bboxstr)
-        print >>fh, _psDefs
-
-        type42 = _type42 + [os.path.join(self.basepath, name) + '.ttf' \
-                 for name in bakoma_fonts]
-        for font in type42:
-            font = str(font)  # todo: handle unicode filenames
-            print >>fh, _psFonts % (os.path.basename(font),
-                                    encodeTTFasPS(font))
-        print >>fh, renderer.get_ps()
 
         self.figure.set_facecolor(origfacecolor)
         self.figure.set_edgecolor(origedgecolor)
 
-    
+        # write the PostScript headers
+        if isEPSF:
+            print >>fh, "%!PS-Adobe-3.0 EPSF-3.0"
+        else:
+            print >>fh, "%!PS-Adobe-3.0"
+        if title: print >>fh, "%%Title: "+title
+        print >>fh, ("%%Creator: matplotlib version "
+                     +__version__+", http://matplotlib.sourceforge.net/")
+        print >>fh, "%%CreationDate: "+datetime.today().ctime()
+        if not isEPSF:
+            if paperWidth > paperHeight:
+                ostr="Landscape"
+            else:
+                ostr="Portrait"
+            print >>fh, "%%Orientation: "+ostr
+        print >>fh, "%%%%BoundingBox: %d %d %d %d" % (llx, lly, urx, ury)
+        if not isEPSF: print >>fh, "%%Pages: 1"
+        print >>fh, "%%EndComments"
+        
+        type42 = _type42 + [os.path.join(self.basepath, name) + '.ttf' \
+                            for name in bakoma_fonts]
+        print >>fh, "%%BeginProlog"
+        print >>fh, "/mpldict %d dict def"%(len(_psDefs)+len(type42))
+        print >>fh, "mpldict begin"
+        for d in _psDefs:
+            d=d.strip()
+            for l in d.split('\n'):
+                print >>fh, l.strip()
+        for font in type42:
+            font = str(font)  # todo: handle unicode filenames
+            print >>fh, "%%BeginFont: "+FT2Font(font).postscript_name
+            print >>fh, encodeTTFasPS(font)
+            print >>fh, "%%EndFont"
+        print >>fh, "%%EndProlog"
+        
+        if not isEPSF: print >>fh, "%%Page: 1 1"
+        print >>fh, "mpldict begin"
+        print >>fh, "gsave"
+        print >>fh, "%s translate"%_nums_to_str( (xo, yo) )
+        if rotation:
+            print >>fh, "%d rotate"%rotation
+        print >>fh, "%s clipbox"%_nums_to_str( (width*72, height*72, 0, 0) )
+
+        # write the figure
+        print >>fh, renderer.get_ps()
+        origfacecolor = self.figure.get_facecolor()
+        origedgecolor = self.figure.get_edgecolor()
+        self.figure.set_facecolor(facecolor)
+        self.figure.set_edgecolor(edgecolor)
+
+        renderer = RendererPS(width, height, fh)
+        self.figure.draw(renderer)
+
+        self.figure.set_facecolor(origfacecolor)
+        self.figure.set_edgecolor(origedgecolor)
+
+        # write the trailer
+        print >>fh, "grestore"
+        print >>fh, "end"
+        print >>fh, "showpage"
+
+        if not isEPSF: print >>fh, "%%EOF"
+        if needsClose: fh.close()
+
 class FigureManagerPS(FigureManagerBase):
     pass
 
-    
+
 FigureManager = FigureManagerPS
 error_msg = error_msg_ps
 
 
-_psProlog = """\
-%%!%s
-%%%% Created by matplotlib http://matplotlib.sourceforge.net
-%%%s
-%%%%EndComments
+# The following Python dictionary _psDefs contains the entries for the
+# PostScript dictionary mpldict.  This dictionary implements most of
+# the matplotlib primitives and some abbreviations.
+#
+# References:
+# http://www.adobe.com/products/postscript/pdfs/PLRM.pdf
+# http://www.mactech.com/articles/mactech/Vol.09/09.04/PostscriptTutorial/
+# http://www.math.ubc.ca/people/faculty/cass/graphics/text/www/
+#
+# Some comments about the implementation:
+#
+# Drawing ellipses:
+#
+# ellipse adds a counter-clockwise segment of an elliptical arc to the
+# current path. The ellipse procedure takes six operands: the x and y
+# coordinates of the center of the ellipse (the center is defined as
+# the point of intersection of the major and minor axes), the
+# ``radius'' of the ellipse in the x direction, the ``radius'' of the
+# ellipse in the y direction, the starting angle of the elliptical arc
+# and the ending angle of the elliptical arc.
+#
+# The basic strategy used in drawing the ellipse is to translate to
+# the center of the ellipse, scale the user coordinate system by the x
+# and y radius values, and then add a circular arc, centered at the
+# origin with a 1 unit radius to the current path. We will be
+# transforming the user coordinate system with the translate and
+# rotate operators to add the elliptical arc segment but we don't want
+# these transformations to affect other parts of the program. In other
+# words, we would like to localize the effect of the transformations.
+# Usually the gsave and grestore operators would be ideal candidates
+# for this task.  Unfortunately gsave and grestore are inappropriate
+# for this situation because we cannot save the arc segment that we
+# have added to the path. Instead we will localize the effect of the
+# transformations by saving the current transformation matrix and
+# restoring it explicitly after we have added the elliptical arc to
+# the path.
 
-%%BeginProlog
-/inch {72 mul} def
-%%%%EndProlog
-"""
-
-_psFonts = """\
-%%BeginFont: %s
-%s
-%%EndFont
-"""
-
-_psDefs = """
-/gsr {gsave stroke grestore} def
-
-/l { newpath moveto lineto } def
-
-% http://www.mactech.com/articles/mactech/Vol.09/09.04/PostscriptTutorial/
-
-/box %called as: leftx bottomy xdimension ydimension box
-{
-/yval exch def 
-/xval exch def
-newpath
-moveto
-0 yval rlineto
-xval 0 rlineto
-0 yval neg rlineto
-closepath
-}
-bind def
-
-/clipbox %called as: leftx bottomy xdimension ydimension box
-{
-/yval exch def
-/xval exch def
-newpath
-moveto
-0 yval rlineto
-xval 0 rlineto
-0 yval neg rlineto
-closepath
-clip
-}
-bind def
-
-/make-polygon
-{
-3 dict
-begin
-  /a exch def
-  /n a length def
-  n 1 gt
-    {
-    a 0 get 0 get a 0 get 1 get moveto
-    1 1 n 1 sub \
-    {
-     /i exch def
-     a i get 0 get   a i get 1 get lineto
-    }
-    for
-    }
-  if
- closepath
-end
-
-}
-def
-
-/mtrx matrix def                            % Allocate a matrix for the save
-					    % matrix operation below.
-/ellipse                                    % ellipse adds a counter-clockwise
-  { /endangle exch def                      % segment of an elliptical arc to
-    /startangle exch def                    % the current path. The ellipse
-    /yrad exch def                          % procedure takes six operands:
-    /xrad exch def                          % the x and y coordinates of the
-    /y exch def                             % center of the ellipse (the
-    /x exch def                             % center is defined as the point
-					    % of intersection of the major and
-					    % minor axes), the ``radius'' of
-					    % the ellipse in the x direction,
-					    % the ``radius'' of the ellipse in
-					    % the y direction, the starting
-					    % angle of the elliptical arc and
-					    % the ending angle of the
-					    % elliptical arc.
-							     
-					    % The basic strategy used in
-					    % drawing the ellipse is to
-					    % translate to the center of the
-					    % ellipse, scale the user
-					    % coordinate system by the x and y
-					    % radius values, and then add a
-					    % circular arc, centered at the
-					    % origin with a 1 unit radius to
-					    % the current path. We will be
-					    % transforming the user coordinate
-					    % system with the translate and
-					    % rotate operators to add the
-					    % elliptical arc segment but we
-					    % don't want these transformations
-					    % to affect other parts of the
-					    % program. In other words, we
-					    % would like to localize the
-					    % effect of the transformations.
-					    % Usually the gsave and grestore
-					    % operators would be ideal
-					    % candidates for this task.
-					    % Unfortunately gsave and grestore
-					    % are inappropriate for this
-					    % situation because we cannot save
-					    % the arc segment that we have
-					    % added to the path. Instead we
-					    % will localize the effect of the
-					    % transformations by saving the
-					    % current transformation matrix
-					    % and restoring it explicitly
-					    % after we have added the
-					    % elliptical arc to the path.
-									 
-    /savematrix mtrx currentmatrix def      % Save the current transformation.
-    x y translate                           % Translate to the center of the
-					    % ellipse.
-    xrad yrad scale                         % Scale by the x and y radius
-					    % values.
-    0 0 1 startangle endangle arc           % Add the arc segment to the path.
-    savematrix setmatrix                    % Restore the transformation.
-  } def
-
-"""
-         
+# The usage comments use the notation of the operator summary
+# in the PostScript Language reference manual.
+_psDefs = [
+    # x y  *m*  -
+    "/m { moveto } bind def",
+    # x y  *l*  -
+    "/l { lineto } bind def",
+    # x y  *r*  -
+    "/r { rlineto } bind def",
+    # x0 y0 x1 y1  *line*  -
+    "/line { newpath m l } bind def",
+    # w h x y  *box*  -
+    """/box {
+      newpath
+      m
+      1 index 0 r
+      0 exch r
+      neg 0 r
+      closepath
+    } bind def""",
+    # w h x y  *clipbox*  -
+    """/clipbox {
+      box
+      clip
+    } bind def""",
+    # angle1 angle2 rx ry x y  *ellipse*  -
+    """/ellipse {
+      newpath
+      matrix currentmatrix 7 1 roll
+      translate
+      scale
+      0 0 1 5 3 roll arc
+      setmatrix
+    } bind def"""
+]
