@@ -57,7 +57,7 @@ The bbox methods are
   intervalx()         - return the x Interval instance
   intervaly()         - return the y interval instance
   get_bounds()        - get the left, bottom, width, height bounding tuple
-  update(xys, ignore) - update the boox to bound all the xy tuples in
+  update(xys, ignore) - update the bbox to bound all the xy tuples in
       xys; if ignore is true ignore the current contents of bbox and
       just bound the tuples.  If ignore is false, bound self + tuples
   width()             - return the width of the bbox
@@ -85,7 +85,7 @@ The signature of a separable transformation instance is
 
   trans = SeparableTransformation(bbox1, bbox2, funcx, funcy)
 
-where funcx and funcy operatate on x and y.  The typical linear
+where funcx and funcy operate on x and y.  The typical linear
 coordinate transformation maps one bounding box to another, with funcx
 and funcy both identity.  Eg,
 
@@ -103,19 +103,26 @@ a, b, c, d, tx, ty.  These give the values of the matrix transformation
   [xo  =  |a  c| [xi  + [tx      
    yo]    |b  d|  yi]    ty]
 
+where if sx, sy are the scaling components, tx, y are the translation
+components, and alpha is the rotation
 
-From a user persepective, the most important Tranformation methods are
+   a = sx*cos(alpha);
+   b = -sx*sin(alpha);
+   c = sy*sin(alpha);
+   d = sy*cos(alpha);
+
+From a user perspective, the most important Tranformation methods are
 
 All transformations
 -------------------
   freeze()              - eval and freeze the lazy objects
-  thaw()                - release the laszy objects
+  thaw()                - release the lazy objects
 
   xy_tup(xy)            - transform the tuple (x,y)
   seq_x_y(x, y)         - transform the python sequences x and y
   numerix_x_y(x, y)     - x and y are numerix 1D arrays
   seq_xy_tups(seq)      - seq is a sequence of xy tuples
-  inverse_xy_tup(xy)    - apply the incerse transformation to tuple xy 
+  inverse_xy_tup(xy)    - apply the inverse transformation to tuple xy 
 
   set_offset(xy, trans) - xy is an x,y tuple and trans is a
     Transformation instance.  This will apply a post transformational
@@ -148,8 +155,8 @@ but should use the helper functions defined in this module.
   one                         - return Value(1)
   origin                      - return Point(zero(), zero())
   unit_bbox                   - return the 0,0 to 1,1 bounding box
-  identity_affine             - An affine idenitity transformation
-  identity_transform          - An indentity separable transformation
+  identity_affine             - An affine identity transformation
+  identity_transform          - An identity separable transformation
   translation_transform       - a pure translational affine
   scale_transform             - a pure scale affine
   scale_sep_transform         - a pure scale separable transformation
@@ -178,9 +185,9 @@ but should use the helper functions defined in this module.
 
 The units/transform_unit.py code has many examples.
 """
-from _transforms import Value, Point, Bbox, Affine
-from _transforms import IDENTITY, LOG10, Func, FuncXY, PolarXY
-from _transforms import SeparableTransformation
+from _transforms import Value, Point, Interval, Bbox, Affine
+from _transforms import IDENTITY, LOG10, POLAR, Func, FuncXY
+from _transforms import SeparableTransformation, NonseparableTransformation
 
 def zero(): return Value(0)
 
@@ -195,12 +202,6 @@ def unit_bbox():
     """
     return  Bbox( origin(), Point( one(), one() ) )
 
-def identity_funcxy():
-    """
-    Get  funcxy instance that maps x,y -> x,y
-    """
-    return FuncXY(Func(IDENTITY), Func(IDENTITY))
-
 def identity_affine():
     """
     Get an affine transformation that maps x,y -> x,y
@@ -245,15 +246,6 @@ def scale_sep_transform(sx, sy):
         bboxin, bboxout,
         Func(IDENTITY), Func(IDENTITY))
                                     
-def scale_translation_transform(tx, ty, sx, sy):
-    """
-    Return a pure scale and translation transformation; tx, ty, sx and
-    sy are LazyValue instances (Values or binary opertations on
-    values)
-    """
-    affine = Affine(sx, zero(), zero(), sy, tx, ty)
-    func = identity_funcxy()
-    return Transformation( affine, func)
 
     
 def bound_vertices(verts):
